.. :changelog:

History
-------

0.3.4 (2015-07-21)
++++++++++++++++++

* Patch: mock removed from reqs & ipython notebook improved

0.3.4 (2015-07-21)
++++++++++++++++++

* Requirements parser code added to setup.py

0.3.3 (2015-07-20)
++++++++++++++++++

* Requirements for Pandas and Numpy added to setup.py

0.3.2 (2015-07-20)
++++++++++++++++++

* Minor code cleanup for PyPi distribution.

0.3.0 (2014-07-21)
++++++++++++++++++

* Major restructuring and test environment setup.


0.2.0 (2013-12-18)
++++++++++++++++++

* No major updates to the code but unittests added and the project setup evolved.


0.1.0 (2013-12-16)
++++++++++++++++++

* First push to Github repo - still buggy.
